==> core-react-0.8.0.tgz: package/es/Select/Select/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import cx from 'classnames';
import invariant from 'invariant';
import PropTypes from 'prop-types';
import React, { Component } from 'react';
import dataFilter from '../../_utils/dataFilter';
import shouldComponentUpdate from '../../_utils/shouldComponentUpdate';
import Input from '../../Input';
import SelectDropdown from '../../SelectDropdown';
import TextOverflow from '../../TextOverflow';


var Select = /*#__PURE__*/function (_Component) {
  _inherits(Select, _Component);

  function Select(props) {
    var _this;

    _classCallCheck(this, Select);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Select).call(this));

    _defineProperty(_assertThisInitialized(_this), "shouldComponentUpdate", shouldComponentUpdate);

    _defineProperty(_assertThisInitialized(_this), "handleLoad", function (data) {
      var url = _this.props.url;
      data = dataFilter(_assertThisInitialized(_this), data) || [];
      invariant(Array.isArray(data), "`Select` data should be `Array`, check the response of `".concat(url, "` or the return value of `dataFilter`."));

      _this.setState({
        data: data
      });
    });

    _defineProperty(_assertThisInitialized(_this), "handleSearch", function (searchValue) {
      _this.setState({
        searchValue: searchValue,
        index: -1
      });
    });

    _defineProperty(_assertThisInitialized(_this), "handleDropToggle", function (open) {
      _this.props.searchable && open && setTimeout(function () {
        _this.refs.clearableInput && _this.refs.clearableInput.focus();
      }, 0);
    });

    _this.state = {
      data: props.data || [],
      index: -1,
      value: 'value' in props ? props.value : props.defaultValue
    };
    return _this;
  }

  _createClass(Select, [{
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      var state = {};
      'value' in nextProps && (state.value = nextProps.value);
      'data' in nextProps && (state.data = nextProps.data);
      this.setState(state);
    }
  }, {
    key: "handleSelect",
    value: function handleSelect(value, item) {
      this.refs.dropdown.close();
      this.setState({
        value: value
      });
      this.props.onChange && this.props.onChange(value, item);
    }
  }, {
    key: "handleKeyDown",
    value: function handleKeyDown(options, e) {
      var key = e.key;
      var index = this.state.index;

      if (key === 'ArrowDown' || key === 'ArrowUp') {
        if (key === 'ArrowDown') {
          if (index === options.length - 1) index = 0;else index++;
        }

        if (key === 'ArrowUp') {
          e.preventDefault();
          if (index === 0) index = options.length - 1;else index--;
        }

        this.setState({
          index: index
        });
      }

      if (key === 'Enter') {
        var props = options[index].props;
        this.handleSelect(props.value, props.data || props);
      }
    }
  }, {
    key: "getOptionsWithProps",
    value: function getOptionsWithProps(onMatch) {
      var _this2 = this;

      var _this$props = this.props,
          children = _this$props.children,
          render = _this$props.render,
          defaultOption = _this$props.defaultOption;
      var res;

      if (children) {
        res = React.Children.map(children, this.getOptionWithProps.bind(this, onMatch));
      } else {
        res = this.state.data.map(function (item, i) {
          return _this2.getOptionWithProps(onMatch, render.call(_this2, item, i), i, item);
        });
      }

      if (defaultOption) {
        res.unshift(this.getOptionWithProps(onMatch, defaultOption, -1));
      }

      return res;
    }
  }, {
    key: "getOptionWithProps",
    value: function getOptionWithProps(onMatch, option, i, dataItem) {
      if (!option) return;
      var _option$props = option.props,
          value = _option$props.value,
          children = _option$props.children;
      var selected = false;

      if (this.state.value === value) {
        onMatch && onMatch(children);
        selected = true;
      }

      return React.cloneElement(option, {
        data: dataItem,
        selected: selected,
        key: i,
        onClick: this.handleSelect.bind(this, value, dataItem || option.props)
      });
    }
  }, {
    key: "filterBySearchValue",
    value: function filterBySearchValue(options) {
      var searchValue = this.state.searchValue;
      if (!searchValue) return options;
      return options.filter(function (option) {
        var _option$props2 = option.props,
            value = _option$props2.value,
            children = _option$props2.children;
        if (!value && value !== 0) return false;
        return children.indexOf(searchValue) !== -1 || String(value).indexOf(searchValue) !== -1;
      });
    }
  }, {
    key: "shouldSearchable",
    value: function shouldSearchable(options) {
      if (!this.props.searchable) return options;
      var index = this.state.index;
      return options.map(function (option, i) {
        return React.cloneElement(option, {
          active: index === i
        });
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          children = _this$props2.children,
          className = _this$props2.className,
          defaultValue = _this$props2.defaultValue,
          onChange = _this$props2.onChange,
          data = _this$props2.data,
          dataFilter = _this$props2.dataFilter,
          defaultOption = _this$props2.defaultOption,
          size = _this$props2.size,
          placeholder = _this$props2.placeholder,
          searchPlaceholder = _this$props2.searchPlaceholder,
          searchable = _this$props2.searchable,
          noOptionsContent = _this$props2.noOptionsContent,
          noMatchingContent = _this$props2.noMatchingContent,
          other = _objectWithoutProperties(_this$props2, ["children", "className", "defaultValue", "onChange", "data", "dataFilter", "defaultOption", "size", "placeholder", "searchPlaceholder", "searchable", "noOptionsContent", "noMatchingContent"]);

      var _this$state = this.state,
          value = _this$state.value,
          searchValue = _this$state.searchValue;
      delete other.value;
      delete other.render;
      var title = null;
      var optionsWithProps = this.getOptionsWithProps(function (children) {
        return title = children;
      });
      optionsWithProps = this.filterBySearchValue(optionsWithProps);
      optionsWithProps = this.shouldSearchable(optionsWithProps);
      var classNames = cx("".concat("waui", "-select"), _defineProperty({}, "".concat("waui", "-select_").concat(size), size), className);
      var optionsClassNames = cx("".concat("waui", "-select__options"), _defineProperty({}, "".concat("waui", "-select__options_").concat(size), size));

      if (!title) {
        if (!value && !defaultOption) {
          title = placeholder;
        }

        if (value) {
          title = noMatchingContent;
        }
      }

      var Title = React.createElement(TextOverflow, null, React.createElement("div", {
        className: "".concat("waui", "-select__title")
      }, title));
      return React.createElement(SelectDropdown, _extends({
        ref: "dropdown",
        className: classNames,
        title: Title,
        onLoad: this.handleLoad,
        hasPropValue: 'value' in this.props || 'defaultValue' in this.props,
        onToggle: this.handleDropToggle,
        caret: true
      }, other), searchable && React.createElement(Input, {
        ref: "clearableInput",
        className: "".concat("waui", "-select__search-input"),
        value: searchValue,
        placeholder: searchPlaceholder,
        onChange: this.handleSearch,
        onKeyDown: this.handleKeyDown.bind(this, optionsWithProps)
      }), React.createElement("ul", {
        className: optionsClassNames
      }, optionsWithProps && optionsWithProps.length ? optionsWithProps : React.createElement("li", {
        className: "".concat("waui", "-select__option")
      }, noOptionsContent)));
    }
  }]);

  return Select;
}(Component);

Select.defaultProps = {
  placeholder: '请选择',
  searchPlaceholder: '请输入关键词搜索',
  noOptionsContent: '无选项',
  noMatchingContent: '无匹配选项'
};
Select.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,

  /** 选中的值 */
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),

  /** 初始化时选中的值（不可控） */
  defaultValue: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),

  /** 切换选择后的回调，function(value, item)，当前数据项或 option.props */
  onChange: PropTypes.func,

  /** 数据源，结合 render 属性定义 Option 渲染逻辑 */
  data: PropTypes.array,

  /** URL 数据源 */
  url: PropTypes.string,

  /** URL 数据源模式数据过滤，参数为服务器返回的数据，返回处理后的数据 */
  dataFilter: PropTypes.func,

  /** data 或 url 方式时 Option 渲染回调，参数为当前数据和索引，返回一个 Option */
  render: PropTypes.func,

  /** data 或 url 方式时默认的 Option，通常针对空值时的选项 */
  defaultOption: PropTypes.element,

  /** 无 `value` 且无选项匹配时 Select 显示的内容，默认 `请选择` */
  placeholder: PropTypes.string,

  /** 是否可搜索，搜索范围为 Option 的 value 和 children */
  searchable: PropTypes.bool,

  /** 搜索框 placeholder，默认`请输入关键词搜索` */
  searchPlaceholder: PropTypes.string,

  /** 是否禁用 */
  disabled: PropTypes.bool,

  /** 尺寸 */
  size: PropTypes.oneOf(['sm', 'lg']),

  /** 宽度，默认`100%` */
  width: PropTypes.number,

  /** 无 option 时显示的内容，默认`无选项` */
  noOptionsContent: PropTypes.string,

  /** 有 `value` 但无选项匹配时显示的内容，默认`无匹配选项` */
  noMatchingContent: PropTypes.string,
  customProp: function customProp(_ref) {
    var value = _ref.value,
        onChange = _ref.onChange,
        url = _ref.url,
        render = _ref.render;

    if (value && !onChange) {
      return new Error('You provided a `value` prop without an `onChange` handler');
    }

    if (url && !render) {
      return new Error('You provided a `url` prop without an `render` handler');
    }
  }
};
export default Select;

==> core-react-0.8.2.tgz: package/es/Select/Select/index.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import cx from 'classnames';
import invariant from 'invariant';
import PropTypes from 'prop-types';
import React, { Component } from 'react';
import dataFilter from '../../_utils/dataFilter';
import shouldComponentUpdate from '../../_utils/shouldComponentUpdate';
import Input from '../../Input';
import SelectDropdown from '../../SelectDropdown';
import TextOverflow from '../../TextOverflow';


var Select = /*#__PURE__*/function (_Component) {
  _inherits(Select, _Component);

  function Select(props) {
    var _this;

    _classCallCheck(this, Select);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Select).call(this));

    _defineProperty(_assertThisInitialized(_this), "shouldComponentUpdate", shouldComponentUpdate);

    _defineProperty(_assertThisInitialized(_this), "handleLoad", function (data) {
      var url = _this.props.url;
      data = dataFilter(_assertThisInitialized(_this), data) || [];
      invariant(Array.isArray(data), "`Select` data should be `Array`, check the response of `".concat(url, "` or the return value of `dataFilter`."));

      _this.setState({
        data: data
      });
    });

    _defineProperty(_assertThisInitialized(_this), "handleSearch", function (searchValue) {
      _this.setState({
        searchValue: searchValue,
        index: -1
      });
    });

    _defineProperty(_assertThisInitialized(_this), "handleDropToggle", function (open) {
      _this.props.searchable && open && setTimeout(function () {
        _this.refs.clearableInput && _this.refs.clearableInput.focus();
      }, 0);
    });

    _this.state = {
      data: props.data || [],
      index: -1,
      value: 'value' in props ? props.value : props.defaultValue
    };
    return _this;
  }

  _createClass(Select, [{
    key: "componentWillReceiveProps",
    value: function componentWillReceiveProps(nextProps) {
      var state = {};
      'value' in nextProps && (state.value = nextProps.value);
      'data' in nextProps && (state.data = nextProps.data);
      this.setState(state);
    }
  }, {
    key: "handleSelect",
    value: function handleSelect(value, item) {
      this.refs.dropdown.close();
      this.setState({
        value: value
      });
      this.props.onChange && this.props.onChange(value, item);
    }
  }, {
    key: "handleKeyDown",
    value: function handleKeyDown(options, e) {
      var key = e.key;
      var index = this.state.index;

      if (key === 'ArrowDown' || key === 'ArrowUp') {
        if (key === 'ArrowDown') {
          if (index === options.length - 1) index = 0;else index++;
        }

        if (key === 'ArrowUp') {
          e.preventDefault();
          if (index === 0) index = options.length - 1;else index--;
        }

        this.setState({
          index: index
        });
      }

      if (key === 'Enter') {
        var props = options[index].props;
        this.handleSelect(props.value, props.data || props);
      }
    }
  }, {
    key: "getOptionsWithProps",
    value: function getOptionsWithProps(onMatch) {
      var _this2 = this;

      var _this$props = this.props,
          children = _this$props.children,
          render = _this$props.render,
          defaultOption = _this$props.defaultOption;
      var res;

      if (children) {
        res = React.Children.map(children, this.getOptionWithProps.bind(this, onMatch));
      } else {
        res = this.state.data.map(function (item, i) {
          return _this2.getOptionWithProps(onMatch, render.call(_this2, item, i), i, item);
        });
      }

      if (defaultOption) {
        res.unshift(this.getOptionWithProps(onMatch, defaultOption, -1));
      }

      return res;
    }
  }, {
    key: "getOptionWithProps",
    value: function getOptionWithProps(onMatch, option, i, dataItem) {
      if (!option) return;
      var _option$props = option.props,
          value = _option$props.value,
          children = _option$props.children;
      var selected = false;

      if (this.state.value === value) {
        onMatch && onMatch(children);
        selected = true;
      }

      return React.cloneElement(option, {
        data: dataItem,
        selected: selected,
        key: i,
        onClick: this.handleSelect.bind(this, value, dataItem || option.props)
      });
    }
  }, {
    key: "filterBySearchValue",
    value: function filterBySearchValue(options) {
      var searchValue = this.state.searchValue;
      if (!searchValue) return options;
      return options.filter(function (option) {
        var _option$props2 = option.props,
            value = _option$props2.value,
            children = _option$props2.children;
        if (!value && value !== 0) return false;
        return children.indexOf(searchValue) !== -1 || String(value).indexOf(searchValue) !== -1;
      });
    }
  }, {
    key: "shouldSearchable",
    value: function shouldSearchable(options) {
      if (!this.props.searchable) return options;
      var index = this.state.index;
      return options.map(function (option, i) {
        return React.cloneElement(option, {
          active: index === i
        });
      });
    }
  }, {
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          children = _this$props2.children,
          className = _this$props2.className,
          defaultValue = _this$props2.defaultValue,
          onChange = _this$props2.onChange,
          data = _this$props2.data,
          dataFilter = _this$props2.dataFilter,
          defaultOption = _this$props2.defaultOption,
          size = _this$props2.size,
          placeholder = _this$props2.placeholder,
          searchPlaceholder = _this$props2.searchPlaceholder,
          searchable = _this$props2.searchable,
          noOptionsContent = _this$props2.noOptionsContent,
          noMatchingContent = _this$props2.noMatchingContent,
          other = _objectWithoutProperties(_this$props2, ["children", "className", "defaultValue", "onChange", "data", "dataFilter", "defaultOption", "size", "placeholder", "searchPlaceholder", "searchable", "noOptionsContent", "noMatchingContent"]);

      var _this$state = this.state,
          value = _this$state.value,
          searchValue = _this$state.searchValue;
      delete other.value;
      delete other.render;
      var title = null;
      var optionsWithProps = this.getOptionsWithProps(function (children) {
        return title = children;
      });
      optionsWithProps = this.filterBySearchValue(optionsWithProps);
      optionsWithProps = this.shouldSearchable(optionsWithProps);
      var classNames = cx("".concat("waui", "-select"), _defineProperty({}, "".concat("waui", "-select_").concat(size), size), className);
      var optionsClassNames = cx("".concat("waui", "-select__options"), _defineProperty({}, "".concat("waui", "-select__options_").concat(size), size));

      if (!title) {
        if (!value && !defaultOption) {
          title = placeholder;
        }

        if (value) {
          title = noMatchingContent;
        }
      }

      var Title = /*#__PURE__*/React.createElement(TextOverflow, null, /*#__PURE__*/React.createElement("div", {
        className: "".concat("waui", "-select__title")
      }, title));
      return (/*#__PURE__*/React.createElement(SelectDropdown, _extends({
          ref: "dropdown",
          className: classNames,
          title: Title,
          onLoad: this.handleLoad,
          hasPropValue: 'value' in this.props || 'defaultValue' in this.props,
          onToggle: this.handleDropToggle,
          caret: true
        }, other), searchable && /*#__PURE__*/React.createElement(Input, {
          ref: "clearableInput",
          className: "".concat("waui", "-select__search-input"),
          value: searchValue,
          placeholder: searchPlaceholder,
          onChange: this.handleSearch,
          onKeyDown: this.handleKeyDown.bind(this, optionsWithProps)
        }), /*#__PURE__*/React.createElement("ul", {
          className: optionsClassNames
        }, optionsWithProps && optionsWithProps.length ? optionsWithProps : /*#__PURE__*/React.createElement("li", {
          className: "".concat("waui", "-select__option")
        }, noOptionsContent)))
      );
    }
  }]);

  return Select;
}(Component);

Select.defaultProps = {
  placeholder: '请选择',
  searchPlaceholder: '请输入关键词搜索',
  noOptionsContent: '无选项',
  noMatchingContent: '无匹配选项'
};
Select.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,

  /** 选中的值 */
  value: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),

  /** 初始化时选中的值（不可控） */
  defaultValue: PropTypes.oneOfType([PropTypes.string, PropTypes.number]),

  /** 切换选择后的回调，function(value, item)，当前数据项或 option.props */
  onChange: PropTypes.func,

  /** 数据源，结合 render 属性定义 Option 渲染逻辑 */
  data: PropTypes.array,

  /** URL 数据源 */
  url: PropTypes.string,

  /** URL 数据源模式数据过滤，参数为服务器返回的数据，返回处理后的数据 */
  dataFilter: PropTypes.func,

  /** data 或 url 方式时 Option 渲染回调，参数为当前数据和索引，返回一个 Option */
  render: PropTypes.func,

  /** data 或 url 方式时默认的 Option，通常针对空值时的选项 */
  defaultOption: PropTypes.element,

  /** 无 `value` 且无选项匹配时 Select 显示的内容，默认 `请选择` */
  placeholder: PropTypes.string,

  /** 是否可搜索，搜索范围为 Option 的 value 和 children */
  searchable: PropTypes.bool,

  /** 搜索框 placeholder，默认`请输入关键词搜索` */
  searchPlaceholder: PropTypes.string,

  /** 是否禁用 */
  disabled: PropTypes.bool,

  /** 尺寸 */
  size: PropTypes.oneOf(['sm', 'lg']),

  /** 宽度，默认`100%` */
  width: PropTypes.number,

  /** 无 option 时显示的内容，默认`无选项` */
  noOptionsContent: PropTypes.string,

  /** 有 `value` 但无选项匹配时显示的内容，默认`无匹配选项` */
  noMatchingContent: PropTypes.string,
  customProp: function customProp(_ref) {
    var value = _ref.value,
        onChange = _ref.onChange,
        url = _ref.url,
        render = _ref.render;

    if (value && !onChange) {
      return new Error('You provided a `value` prop without an `onChange` handler');
    }

    if (url && !render) {
      return new Error('You provided a `url` prop without an `render` handler');
    }
  }
};
export default Select;
